package com.eneraptor.hci

class SysStateController {

	def reportService
	def hciLogicCommService
	
    def main = {
		
		def crit1 = DeviceInfo.createCriteria()
		List inDevices = crit1 {
			and {
				eq("inputDevice",true)
				eq("hwSet",session.hwSet)
			}
			order("friendlyName","asc")
		}
		
		List inDevicesData = new ArrayList()
		inDevices.each {
			Map inDeviceDataEntry = new HashMap()
			inDeviceDataEntry['friendlyName'] = it.friendlyName
			inDeviceDataEntry['icon'] = it.iconPath
			inDeviceDataEntry['loggedData'] = LoggedData.findByDeviceId(it.deviceId, [sort:'dateRecieved', order:'desc'])	
			inDevicesData << inDeviceDataEntry
		}
		
		def crit2 = DeviceInfo.createCriteria()
		List outDevices = crit2 {
			and {
				eq("outputDevice",true)
				eq("hwSet",session.hwSet)
			}
			order("friendlyName","asc")
		}

		List outDevicesData = new ArrayList()
		outDevices.each {
			Map outDeviceDataEntry = new HashMap()
			outDeviceDataEntry['friendlyName'] = it.friendlyName
			outDeviceDataEntry['icon'] = it.iconPath
			outDeviceDataEntry['loggedData'] = LoggedData.findByDeviceId(it.deviceId, [sort:'dateRecieved', order:'desc'])
			outDevicesData << outDeviceDataEntry
		}
		
		[inDevicesData: inDevicesData, outDevicesData: outDevicesData]
		
	}
	
	def measure = {
		
		def crit1 = DeviceInfo.createCriteria()
		List inDevices = crit1 {
			and {
				eq("inputDevice",true)
				eq("hwSet",session.hwSet)
			}
			order("friendlyName","asc")
		}
		
		List inDevicesData = new ArrayList()
		inDevices.each {
			Map inDeviceDataEntry = new HashMap()
			inDeviceDataEntry['deviceId'] = it.deviceId
			inDeviceDataEntry['friendlyName'] = it.friendlyName
			inDeviceDataEntry['icon'] = it.iconPath
			inDeviceDataEntry['loggedData'] = LoggedData.findByDeviceId(it.deviceId, [sort:'dateRecieved', order:'desc'])
			inDevicesData << inDeviceDataEntry
		}
		
		[inDevicesData: inDevicesData]
		
    }
	
	def measureUpdate = {
		
		List devices = new ArrayList()
		
		DeviceInfo.findAllByInputDevice(true).each {
			if(params[it.deviceId] == "on")
				devices << it.deviceId
		}
		
		def output = "";
		
		if(devices.size == 0) {
			flash['errors'] = "<p>No device was selected. At least one device must be selected.</p>"
			redirect(action: 'measure')
			return false
		}
		
		output += reportService.println("Trying to update measurements manually for devices")
		devices.each {
			output += reportService.println(" - " + it)
		}
		output += reportService.println("Generating request xml")
		
		// generate request xml
		def reqXML = "<todo />"
		
		output += reportService.println("Request xml generated")
		output += reportService.println("Sending request")
		
		// send request
		Map rspXML = hciLogicCommService.getReplyToRequest(reqXML)
		
		if(rspXML['status'] == "error") {
			output += reportService.println("<span style='color:red;'>Error: " + rspXML['content'] + "</span>")
		} else {
			output += reportService.println("<span style='color:red;'>Error: implementation missing - TODO.</span>")
		}
		
		[errorExplanation: output]
		
	}
	
	def actions = {
		
		def crit2 = DeviceInfo.createCriteria()
		List outDevices = crit2 {
			and {
				eq("outputDevice",true)
				eq("hwSet",session.hwSet)
			}
			order("friendlyName","asc")
		}
		
		List outDevicesData = new ArrayList()
		outDevices.each {
			Map outDeviceDataEntry = new HashMap()
			outDeviceDataEntry['deviceId'] = it.deviceId
			outDeviceDataEntry['friendlyName'] = it.friendlyName
			outDeviceDataEntry['icon'] = it.iconPath
			outDeviceDataEntry['loggedData'] = LoggedData.findByDeviceId(it.deviceId, [sort:'dateRecieved', order:'desc'])
			outDevicesData << outDeviceDataEntry
		}
		
		[outDevicesData: outDevicesData]
		
    }
	
}
